[education/rkward] rkward/rbackend/rpackages/rkward: replaced some param=NULL with empty parameters in the rkward R package

m.eik michalke null at kde.org
Sun Sep 10 11:37:33 BST 2023


Git commit bdcc2f966953b6416990b84d6242a345bf1f0d52 by m.eik michalke.
Committed on 10/09/2023 at 12:27.
Pushed by meikm into branch 'master'.

replaced some param=NULL with empty parameters in the rkward R package

M  +4    -4    rkward/rbackend/rpackages/rkward/R/public_graphics.R
M  +19   -7    rkward/rbackend/rpackages/rkward/R/rk.KDE_GUI-functions.R
M  +4    -4    rkward/rbackend/rpackages/rkward/R/rk.demo.R
M  +8    -4    rkward/rbackend/rpackages/rkward/R/rk.edit-functions.R
M  +4    -4    rkward/rbackend/rpackages/rkward/R/rk.label-functions.R
M  +2    -1    rkward/rbackend/rpackages/rkward/R/rk.plugin-functions.R
M  +2    -2    rkward/rbackend/rpackages/rkward/R/rk.print-functions.R
M  +2    -2    rkward/rbackend/rpackages/rkward/R/rk.utility-functions.R
M  +8    -9    rkward/rbackend/rpackages/rkward/R/rk.workspace-functions.R
M  +3    -1    rkward/rbackend/rpackages/rkward/man/rk.capture.output.Rd
M  +3    -3    rkward/rbackend/rpackages/rkward/man/rk.demo.Rd
M  +4    -2    rkward/rbackend/rpackages/rkward/man/rk.edit.Rd
M  +3    -3    rkward/rbackend/rpackages/rkward/man/rk.label.Rd
M  +1    -5    rkward/rbackend/rpackages/rkward/man/rk.load.pluginmaps.Rd
M  +1    -1    rkward/rbackend/rpackages/rkward/man/rk.old.packages.Rd
M  +5    -5    rkward/rbackend/rpackages/rkward/man/rk.show.messages.Rd
M  +5    -6    rkward/rbackend/rpackages/rkward/man/rk.workplace.Rd

https://invent.kde.org/education/rkward/-/commit/bdcc2f966953b6416990b84d6242a345bf1f0d52

diff --git a/rkward/rbackend/rpackages/rkward/R/public_graphics.R b/rkward/rbackend/rpackages/rkward/R/public_graphics.R
index e8dca4449..ab4a7c984 100644
--- a/rkward/rbackend/rpackages/rkward/R/public_graphics.R
+++ b/rkward/rbackend/rpackages/rkward/R/public_graphics.R
@@ -446,13 +446,13 @@
 	}
 	
 	## Recording functions
-	record <- function(devId = dev.cur (), isManaged = NULL, action = "", callUHA = TRUE, nextplot.pkg = "", nextplot.call = NA_character_)
+	record <- function(devId = dev.cur (), isManaged, action = "", callUHA = TRUE, nextplot.pkg = "", nextplot.call = NA_character_)
 	{
 		# callUHA is not really utilized, but there to provide a flixibility to not call 
 		# .rk.update.hist.action () when not needed
 		devId <- as.character (devId)
 		
-		if (is.null (isManaged)) isManaged <- .is.device.managed (devId)
+		if (missing (isManaged)) isManaged <- .is.device.managed (devId)
 		if (!isManaged) return (invisible ())
 		
 		if (histPositions[[devId]]$is.this.dev.new) {
@@ -806,11 +806,11 @@
 	}
 	
 	## Utility / print functions:
-	getDevSummary <- function (devId = NULL)
+	getDevSummary <- function (devId)
 	{
 		message ("History length   : ", sP.length)
 		message ("History size (KB): ", round (object.size (savedPlots) / 1024, 2))
-		if (is.null (devId)) {
+		if (missing (devId)) {
 			.tmp.df <- data.frame (
 				pNew = sapply (histPositions, "[[", "is.this.plot.new"),
 				dNew = sapply (histPositions, "[[", "is.this.dev.new"),
diff --git a/rkward/rbackend/rpackages/rkward/R/rk.KDE_GUI-functions.R b/rkward/rbackend/rpackages/rkward/R/rk.KDE_GUI-functions.R
index cf6cc3331..467034b79 100755
--- a/rkward/rbackend/rpackages/rkward/R/rk.KDE_GUI-functions.R
+++ b/rkward/rbackend/rpackages/rkward/R/rk.KDE_GUI-functions.R
@@ -27,7 +27,7 @@
 #' @param message a string for the content of the message box.
 #' @param msg like \code{message}, only the argument was renamed to mimic the formals of
 #'   \code{askYesNo}.
-#' @param caption a string for title of the message box.
+#' @param caption a string for title of the message box. Optional for \code{rk.select.file} and \code{rk.choose.dir}.
 #' @param button.yes a string for the text label of the \bold{Yes} button. Can
 #'   be an empty string (\code{""}), in which case the button is not displayed
 #'   at all. Note that the default value of "yes" (lower case) means to use a default
@@ -169,15 +169,19 @@
 # drop-in-replacement for tk_select.list()
 #' @export
 #' @rdname rk.show.messages
-"rk.select.list" <- function (list, preselect = NULL, multiple = FALSE, title = NULL) {
-	preselect <- as.character (preselect)
+"rk.select.list" <- function (list, preselect, multiple = FALSE, title) {
+    if (missing (preselect)) {
+        preselect <- character(0)
+    } else {
+        preselect <- as.character (preselect)
+    }
 	preselect.len = length (preselect)
 	list <- as.character (list)
 	list.len <- length (list)
 	params <- list ()
 
 	# serialize all parameters
-	params[1] <- if(is.null(title)) "" else as.character (title)
+	params[1] <- if(missing (title)) "" else as.character (title)
 	if (multiple) params[2] <- "multi"
 	else params[2] <- "single"
 	params[3] <- as.character (preselect.len)
@@ -204,14 +208,22 @@
 #'    \code{"dir"} (select a directory), or \code{"newfile"} (set path for a new file).
 #' @export
 #' @rdname rk.show.messages
-"rk.select.file" <- function(caption = NULL, initial = NULL, filter = '*', mode=c("file", "files", "dir", "newfile")) {
+"rk.select.file" <- function(caption, initial, filter = '*', mode=c("file", "files", "dir", "newfile")) {
     mode <- match.arg(mode)
-	.rk.do.plain.call ("choosefile", list(caption, initial, filter, mode[1]))
+	.rk.do.plain.call (
+        "choosefile",
+        list(
+            if (missing (caption)) "" else caption,
+            if (missing (initial)) "" else initial,
+            filter,
+            mode[1]
+        )
+    )
 }
 
 # wrapper for dirs only
 #' @export
 #' @rdname rk.show.messages
-"rk.choose.dir" <- function(caption = NULL, initial = NULL, filter = '*'){
+"rk.choose.dir" <- function(caption, initial, filter = '*'){
     rk.select.file(caption = caption, initial = initial, filter = filter, mode="dir")
 }
diff --git a/rkward/rbackend/rpackages/rkward/R/rk.edit-functions.R b/rkward/rbackend/rpackages/rkward/R/rk.edit-functions.R
index da28e3a92..b247954d2 100644
--- a/rkward/rbackend/rpackages/rkward/R/rk.edit-functions.R
+++ b/rkward/rbackend/rpackages/rkward/R/rk.edit-functions.R
@@ -19,6 +19,7 @@
 #' 
 #' @aliases rk.edit rk.edit.files rk.show.files rk.show.html
 #' @param x an object to edit.
+#' @param name name of the environment to use (optional).
 #' @param file character vector, filenames to show or edit.
 #' @param title character vector, of the same length as \code{file}; This can
 #'   be used to give descriptive titles to each file, which will be displayed
@@ -50,9 +51,11 @@
 
 #' @export
 #' @rdname rk.edit
-"rk.edit.files" <- function (name=NULL, file="", title=NULL, prompt = TRUE) {
-	if (!is.null(name)) {
-		if (is.null (title)) title = deparse (substitute (name))
+"rk.edit.files" <- function (name, file="", title, prompt = TRUE) {
+	if (missing (name)) {
+		name <- character(0)
+	} else {
+		if (missing (title)) title = deparse (substitute (name))
 		if (file == "") file = tempfile()
 		env = environment(name)
 		dput (name, file = file, control = c("useSource", "keepNA", "keepInteger", "showAttributes"))
@@ -66,10 +69,11 @@
 
 #' @export
 #' @rdname rk.edit
-"rk.show.files" <- function (file = file, header = file, title = NULL, delete.file=FALSE, prompt = TRUE,
+"rk.show.files" <- function (file = file, header = file, title, delete.file=FALSE, prompt = TRUE,
 	delete = delete.file  # For compatibility with earlier versions of R
 )
 {
+	if(missing (title)) title <- character(0)
 	invisible (.Call ("rk.show.files", as.character (file), as.character (header), as.character (title), delete, isTRUE (prompt), PACKAGE="(embedding)"))
 }
 
diff --git a/rkward/rbackend/rpackages/rkward/R/rk.plugin-functions.R b/rkward/rbackend/rpackages/rkward/R/rk.plugin-functions.R
index e270b1176..c6181ee5c 100644
--- a/rkward/rbackend/rpackages/rkward/R/rk.plugin-functions.R
+++ b/rkward/rbackend/rpackages/rkward/R/rk.plugin-functions.R
@@ -111,7 +111,8 @@
 #' ## END NOT RUN
 #' @export
 #' @rdname rk.load.pluginmaps
-"rk.load.pluginmaps" <- function (pluginmap.files=NULL, force.add = TRUE, force.reload = TRUE) {
+"rk.load.pluginmaps" <- function (pluginmap.files, force.add = TRUE, force.reload = TRUE) {
+	if (missing (pluginmap.files)) pluginmap.files <- character(0)
 	.rk.do.plain.call ("loadPluginMaps", c (ifelse (isTRUE (force.add), "force", "noforce"), ifelse (isTRUE (force.reload), "reload", "noreload"), as.character (pluginmap.files)), synchronous=FALSE)
 }
 
diff --git a/rkward/rbackend/rpackages/rkward/R/rk.print-functions.R b/rkward/rbackend/rpackages/rkward/R/rk.print-functions.R
index 20c2efbb6..bad0e2030 100644
--- a/rkward/rbackend/rpackages/rkward/R/rk.print-functions.R
+++ b/rkward/rbackend/rpackages/rkward/R/rk.print-functions.R
@@ -279,8 +279,8 @@
 #'
 #' And arbitrary number of ouptut captures can be started and stopped, and these will form a push/pop stack.
 #'
-#' @param suppress.messages
-#' @param suppress.output output / message are not sent on, neither to surrounding captures, nor as regular output
+#' @param suppress.messages message are not sent on, neither to surrounding captures, nor as regular output.
+#' @param suppress.output like \code{suppress.messages}, but for output.
 #' @param allow.nesting if false, output / message is not sent to surrounding captures, but is sent to regular output (unless suppressed)
 #'
 #' \code{rk.capture.output} Starts capturing output.
diff --git a/rkward/rbackend/rpackages/rkward/R/rk.utility-functions.R b/rkward/rbackend/rpackages/rkward/R/rk.utility-functions.R
index 7476a319c..f92bb9446 100644
--- a/rkward/rbackend/rpackages/rkward/R/rk.utility-functions.R
+++ b/rkward/rbackend/rpackages/rkward/R/rk.utility-functions.R
@@ -121,9 +121,9 @@
 #' 
 #' @export
 "rk.old.packages" <- function (lib.loc = NULL, repos = getOption("repos"), contriburl = contrib.url(repos, type), instPkgs = installed.packages(lib.loc = lib.loc),
-                             method, available = NULL, checkBuilt = FALSE, type = getOption("pkgType")) {
+                             method, available, checkBuilt = FALSE, type = getOption("pkgType")) {
 	if (is.null (lib.loc)) lib.loc <- .libPaths ()
-	if (is.null (available)) available <- available.packages (contriburl=contriburl, method=method)
+	if (missing (available)) available <- available.packages (contriburl=contriburl, method=method)
 
 	seen.packages <- character (0)
 	old <- NULL
diff --git a/rkward/rbackend/rpackages/rkward/man/rk.capture.output.Rd b/rkward/rbackend/rpackages/rkward/man/rk.capture.output.Rd
index 359350bbb..73d0a3518 100644
--- a/rkward/rbackend/rpackages/rkward/man/rk.capture.output.Rd
+++ b/rkward/rbackend/rpackages/rkward/man/rk.capture.output.Rd
@@ -16,7 +16,9 @@ rk.capture.output(
 rk.end.capture.output(highlight = FALSE)
 }
 \arguments{
-\item{suppress.output}{output / message are not sent on, neither to surrounding captures, nor as regular output}
+\item{suppress.messages}{message are not sent on, neither to surrounding captures, nor as regular output.}
+
+\item{suppress.output}{like \code{suppress.messages}, but for output.}
 
 \item{allow.nesting}{if false, output / message is not sent to surrounding captures, but is sent to regular output (unless suppressed)
 
diff --git a/rkward/rbackend/rpackages/rkward/man/rk.demo.Rd b/rkward/rbackend/rpackages/rkward/man/rk.demo.Rd
index d9bba3b33..c540ea64c 100644
--- a/rkward/rbackend/rpackages/rkward/man/rk.demo.Rd
+++ b/rkward/rbackend/rpackages/rkward/man/rk.demo.Rd
@@ -4,15 +4,15 @@
 \alias{rk.demo}
 \title{Opens an R demo script for editing}
 \usage{
-rk.demo(topic, package = NULL, lib.loc = NULL)
+rk.demo(topic, package, lib.loc = NULL)
 }
 \arguments{
 \item{topic}{topic of the example}
 
-\item{package}{package(s) to search for the demo. If NULL (the default), all
+\item{package}{package(s) to search for the demo. If missing (the default), all
 currently loaded packages are searched.}
 
-\item{lib.loc}{Library locations.}
+\item{lib.loc}{Library locations, passed on to \code{\link[base:system.file]{system.file}}.}
 }
 \value{
 Return \code{NULL}, unconditionally.
diff --git a/rkward/rbackend/rpackages/rkward/man/rk.edit.Rd b/rkward/rbackend/rpackages/rkward/man/rk.edit.Rd
index 649d80c8b..e59e66aea 100644
--- a/rkward/rbackend/rpackages/rkward/man/rk.edit.Rd
+++ b/rkward/rbackend/rpackages/rkward/man/rk.edit.Rd
@@ -9,12 +9,12 @@
 \usage{
 rk.edit(x)
 
-rk.edit.files(name = NULL, file = "", title = NULL, prompt = TRUE)
+rk.edit.files(name, file = "", title, prompt = TRUE)
 
 rk.show.files(
   file = file,
   header = file,
-  title = NULL,
+  title,
   delete.file = FALSE,
   prompt = TRUE,
   delete = delete.file
@@ -25,6 +25,8 @@ rk.show.html(url)
 \arguments{
 \item{x}{an object to edit.}
 
+\item{name}{name of the environment to use (optional).}
+
 \item{file}{character vector, filenames to show or edit.}
 
 \item{title}{character vector, of the same length as \code{file}; This can
diff --git a/rkward/rbackend/rpackages/rkward/man/rk.label.Rd b/rkward/rbackend/rpackages/rkward/man/rk.label.Rd
index 46166e1e9..43cf484b7 100644
--- a/rkward/rbackend/rpackages/rkward/man/rk.label.Rd
+++ b/rkward/rbackend/rpackages/rkward/man/rk.label.Rd
@@ -21,7 +21,7 @@ rk.get.short.name(x)
 
 .rk.make.short.name(x)
 
-rk.get.description(..., paste.sep = NULL, is.substitute = FALSE)
+rk.get.description(..., paste.sep, is.substitute = FALSE)
 
 rk.list(...)
 
@@ -36,7 +36,7 @@ rk.list.names(..., deparse.level = 2)
 
 \item{fill}{a logical or character. See Details.}
 
-\item{paste.sep}{a string, used as the \code{collapse} argument for paste}
+\item{paste.sep}{a string, used as the \code{collapse} argument for paste.}
 
 \item{is.substitute}{a logical (not NA). See Details.}
 }
@@ -62,7 +62,7 @@ a character vector of default labels to use as the \code{fill} parameter.
 
 \code{rk.get.description} creates descriptive string(s) for each of the
 arguments in "\code{\dots{}}"; collapsing into a single string using
-\code{paste.sep} (if not NULL). If \code{is.substitute=TRUE}, the arguments
+\code{paste.sep} (if not missing). If \code{is.substitute=TRUE}, the arguments
 will be deparsed, first, which can be useful when using
 \code{rk.get.description} inside a function.
 
diff --git a/rkward/rbackend/rpackages/rkward/man/rk.load.pluginmaps.Rd b/rkward/rbackend/rpackages/rkward/man/rk.load.pluginmaps.Rd
index ee15f6a74..b98dba180 100644
--- a/rkward/rbackend/rpackages/rkward/man/rk.load.pluginmaps.Rd
+++ b/rkward/rbackend/rpackages/rkward/man/rk.load.pluginmaps.Rd
@@ -4,11 +4,7 @@
 \alias{rk.load.pluginmaps}
 \title{(Re-)load the given pluginmap files into the RKWard GUI}
 \usage{
-rk.load.pluginmaps(
-  pluginmap.files = NULL,
-  force.add = TRUE,
-  force.reload = TRUE
-)
+rk.load.pluginmaps(pluginmap.files, force.add = TRUE, force.reload = TRUE)
 }
 \arguments{
 \item{pluginmap.files}{a character vector of file names to add. This may be left empty,
diff --git a/rkward/rbackend/rpackages/rkward/man/rk.old.packages.Rd b/rkward/rbackend/rpackages/rkward/man/rk.old.packages.Rd
index 713a2aedd..6b24df2ec 100644
--- a/rkward/rbackend/rpackages/rkward/man/rk.old.packages.Rd
+++ b/rkward/rbackend/rpackages/rkward/man/rk.old.packages.Rd
@@ -10,7 +10,7 @@ rk.old.packages(
   contriburl = contrib.url(repos, type),
   instPkgs = installed.packages(lib.loc = lib.loc),
   method,
-  available = NULL,
+  available,
   checkBuilt = FALSE,
   type = getOption("pkgType")
 )
diff --git a/rkward/rbackend/rpackages/rkward/man/rk.show.messages.Rd b/rkward/rbackend/rpackages/rkward/man/rk.show.messages.Rd
index 9fede1198..c0c1a7d30 100644
--- a/rkward/rbackend/rpackages/rkward/man/rk.show.messages.Rd
+++ b/rkward/rbackend/rpackages/rkward/man/rk.show.messages.Rd
@@ -29,21 +29,21 @@ rk.askYesNo(
   ...
 )
 
-rk.select.list(list, preselect = NULL, multiple = FALSE, title = NULL)
+rk.select.list(list, preselect, multiple = FALSE, title)
 
 rk.select.file(
-  caption = NULL,
-  initial = NULL,
+  caption,
+  initial,
   filter = "*",
   mode = c("file", "files", "dir", "newfile")
 )
 
-rk.choose.dir(caption = NULL, initial = NULL, filter = "*")
+rk.choose.dir(caption, initial, filter = "*")
 }
 \arguments{
 \item{message}{a string for the content of the message box.}
 
-\item{caption}{a string for title of the message box.}
+\item{caption}{a string for title of the message box. Optional for \code{rk.select.file} and \code{rk.choose.dir}.}
 
 \item{wait}{a logical (not NA) indicating whether the R interpreter should
 wait for the user's action, or run it asynchronously.}
diff --git a/rkward/rbackend/rpackages/rkward/man/rk.workplace.Rd b/rkward/rbackend/rpackages/rkward/man/rk.workplace.Rd
index b9fe9924d..c8700c293 100644
--- a/rkward/rbackend/rpackages/rkward/man/rk.workplace.Rd
+++ b/rkward/rbackend/rpackages/rkward/man/rk.workplace.Rd
@@ -5,17 +5,16 @@
 \alias{rk.restore.workplace}
 \title{Save or restore RKWard workplace}
 \usage{
-rk.save.workplace(file = NULL, description = NULL)
+rk.save.workplace(file, description)
 
-rk.restore.workplace(file = NULL, close.windows = TRUE)
+rk.restore.workplace(file, close.windows = TRUE)
 }
 \arguments{
 \item{file}{a character string giving the url of the file to save to, or
-NULL for automatic selection of a suitable file (see Details).}
+missing for automatic selection of a suitable file (see Details).}
 
 \item{description}{For internal use, only. A character string describing the
-workplace status to save. Generally, you should leave this as the default
-value (\code{NULL}).}
+workplace status to save. Generally, you should not set a value yourself.}
 
 \item{close.windows}{a logical; whether current windows should be closed
 before restoring.}
@@ -30,7 +29,7 @@ a file. \code{rk.restore.workplace} restores an RKWard workplace as saved by
 \code{rk.save.workplace}.
 }
 \details{
-If the \code{file} parameter is omitted (or \code{NULL}), a suitable
+If the \code{file} parameter is omitted (missing), a suitable
 filename is selected automatically. If a workspace has been loaded, this is
 the URL of the workspace with an appended \code{.rkworkplace}. Otherwise a
 filename in the RKWard directory, as generated by



More information about the rkward-tracker mailing list
diff --git a/rkward/rbackend/rpackages/rkward/R/rk.demo.R b/rkward/rbackend/rpackages/rkward/R/rk.demo.R
index 3b66d2220..6dfe4113d 100644
--- a/rkward/rbackend/rpackages/rkward/R/rk.demo.R
+++ b/rkward/rbackend/rpackages/rkward/R/rk.demo.R
@@ -9,9 +9,9 @@
 #' the specification of a topic is mandatory.
 #' 
 #' @param topic topic of the example
 #' @param package package(s) to search for the demo. If NULL (the default), all
 #'   currently loaded packages are searched.
-#' @param lib.loc Library locations.
+#' @param lib.loc Library locations, passed on to \code{\link[base:system.file]{system.file}}.
 #' @return Return \code{NULL}, unconditionally.
 #' @author Thomas Friedrichsmeier \email{rkward-devel@@kde.org}
 #' @seealso \code{\link{rk.edit.files}}, \code{\link{rk.show.files}},
@@ -24,8 +24,8 @@
 #' ## Not run
 #' rk.demo("graphics")
 
-"rk.demo" <- function (topic, package=NULL, lib.loc=NULL) {
-	if (is.null (package)) {
+"rk.demo" <- function (topic, package, lib.loc=NULL) {
+	if (missing (package)) {
 		package <- .packages (lib.loc=lib.loc)
 	}
 
@@ -9,9 +9,9 @@
 #' 
 #' @param topic topic of the example
-#' @param package package(s) to search for the demo. If NULL (the default), all
+#' @param package package(s) to search for the demo. If missing (the default), all
 #'   currently loaded packages are searched.
diff --git a/rkward/rbackend/rpackages/rkward/R/rk.label-functions.R b/rkward/rbackend/rpackages/rkward/R/rk.label-functions.R
index 57f6a90e2..4a842c3eb 100644
--- a/rkward/rbackend/rpackages/rkward/R/rk.label-functions.R
+++ b/rkward/rbackend/rpackages/rkward/R/rk.label-functions.R
@@ -20,7 +20,7 @@
 #' 
 #' \code{rk.get.description} creates descriptive string(s) for each of the
 #' arguments in "\code{\dots{}}"; collapsing into a single string using
 #' \code{paste.sep} (if not NULL). If \code{is.substitute=TRUE}, the arguments
 #' will be deparsed, first, which can be useful when using
 #' \code{rk.get.description} inside a function.
 #' 
@@ -38,7 +38,7 @@
 #' @param label a string, to set the label attribute of an object
 #' @param envir an environment, where the attribute is evaluated
 #' @param fill a logical or character. See Details.
-#' @param paste.sep a string, used as the \code{collapse} argument for paste
+#' @param paste.sep a string, used as the \code{collapse} argument for paste.
 #' @param is.substitute a logical (not NA). See Details.
 #' @return \code{rk.set.label} returns the result of the evaluation of "setting
 #'   the label" while the others return a character vector.
@@ -123,7 +123,7 @@
 # get descriptive strings for each of the arguments in ...
 #' @rdname rk.label
 #' @export
-"rk.get.description" <- function (..., paste.sep=NULL, is.substitute=FALSE) {
+"rk.get.description" <- function (..., paste.sep, is.substitute=FALSE) {
 	args <- list(...)
 	if (is.substitute) {
 		argnames <- list ()
@@ -149,7 +149,7 @@
 		else descript[i] <- paste (shortname, " (", lbl, ")", sep="")
 	}
 
-	if (is.null (paste.sep)) {
+	if (missing (paste.sep)) {
 		descript
 	} else {
 		paste (descript, collapse=paste.sep)
@@ -20,7 +20,7 @@
 #' \code{rk.get.description} creates descriptive string(s) for each of the
 #' arguments in "\code{\dots{}}"; collapsing into a single string using
-#' \code{paste.sep} (if not NULL). If \code{is.substitute=TRUE}, the arguments
+#' \code{paste.sep} (if not missing). If \code{is.substitute=TRUE}, the arguments
 #' will be deparsed, first, which can be useful when using
 #' \code{rk.get.description} inside a function.
diff --git a/rkward/rbackend/rpackages/rkward/R/rk.workspace-functions.R b/rkward/rbackend/rpackages/rkward/R/rk.workspace-functions.R
index 224fb4c7b..7f43b387e 100644
--- a/rkward/rbackend/rpackages/rkward/R/rk.workspace-functions.R
+++ b/rkward/rbackend/rpackages/rkward/R/rk.workspace-functions.R
@@ -9,7 +9,7 @@
 #' a file. \code{rk.restore.workplace} restores an RKWard workplace as saved by
 #' \code{rk.save.workplace}.
 #' 
 #' If the \code{file} parameter is omitted (or \code{NULL}), a suitable
 #' filename is selected automatically. If a workspace has been loaded, this is
 #' the URL of the workspace with an appended \code{.rkworkplace}. Otherwise a
 #' filename in the RKWard directory, as generated by
@@ -21,10 +21,9 @@
 #' 
 #' @aliases rk.save.workplace rk.restore.workplace
 #' @param file a character string giving the url of the file to save to, or
 #'   NULL for automatic selection of a suitable file (see Details).
 #' @param description For internal use, only. A character string describing the
-#'   workplace status to save. Generally, you should leave this as the default
-#'   value (\code{NULL}).
+#'   workplace status to save. Generally, you should not set a value yourself.
 #' @param close.windows a logical; whether current windows should be closed
 #'   before restoring.
 #' @return Both functions return \code{NULL}.
@@ -40,22 +39,22 @@
 #' ## End not run
 #' 
 #' @export
-"rk.save.workplace" <- function (file=NULL, description=NULL) {
-	if (is.null (file)) {
+"rk.save.workplace" <- function (file, description) {
+	if (missing (file)) {
 		file <- rk.get.workspace.url ()
 		if (is.null(file)) file <- rk.get.tempfile.name (prefix="unsaved", extension=".RData", directory=rk.tempdir ())
 		else file <- URLdecode(file)
 		file <- paste (file, "rkworkplace", sep=".")
 	}
-	if (is.null (description)) lines <- .rk.do.plain.call ("workplace.layout", "get")
+	if (missing (description)) lines <- .rk.do.plain.call ("workplace.layout", "get")
 	else lines <- description
 	writeLines (lines, file)
 }
 
 #' @rdname rk.workplace
 #' @export
-"rk.restore.workplace" <- function (file=NULL, close.windows=TRUE) {
-	if (is.null (file)) {
+"rk.restore.workplace" <- function (file, close.windows=TRUE) {
+	if (missing (file)) {
 		if (exists (".rk.workplace.save", envir=globalenv (), inherits=FALSE)) {
 			# For backwards compatibility with workspaces saved by RKWard 0.5.4 and earlier.
 			# TODO: remove in time.
@@ -9,7 +9,7 @@
 #' \code{rk.save.workplace}.
 #' 
-#' If the \code{file} parameter is omitted (or \code{NULL}), a suitable
+#' If the \code{file} parameter is omitted (missing), a suitable
 #' filename is selected automatically. If a workspace has been loaded, this is
 #' the URL of the workspace with an appended \code{.rkworkplace}. Otherwise a
@@ -21,10 +21,9 @@
 #' @aliases rk.save.workplace rk.restore.workplace
 #' @param file a character string giving the url of the file to save to, or
-#'   NULL for automatic selection of a suitable file (see Details).
+#'   missing for automatic selection of a suitable file (see Details).
 #' @param description For internal use, only. A character string describing the